@@ -1,7 +1,7 @@
 // Install script for Enigmail
 
 var err;
-const APP_VERSION="0.95.7.0";
+const APP_VERSION="0.96.0";
 
 
 const ABI_PLATFORM_LINUX="Linux_x86-gcc3";
@@ -47,13 +47,13 @@ function getPlatform() {
   if('platform' in Install) {
     platformStr = new String(Install.platform);
 
-    if (!platformStr.search(/^Macintosh/))
+    if (platformStr.search(/^Macintosh/) == 0)
       platformNode = APP_PLATFORM_MAC;
-    else if (!platformStr.search(/^Win/))
+    else if (platformStr.search(/^Win/) == 0)
       platformNode = APP_PLATFORM_WIN;
     else if (platformStr.search(/Linux/) >= 0)
       platformNode = APP_PLATFORM_LINUX;
-    else if (!platformStr.search(/^OS\/2/))
+    else if (platformStr.search(/^OS\/2/) == 0)
       platformNode = APP_PLATFORM_OS2;
     else
       platformNode = APP_PLATFORM_OTHER;
@@ -107,7 +107,7 @@ if (!verifyDiskSpace(fProgram, srDest)) {
     addDirectory("", "platform/"+ABI_PLATFORM_OS2+"/components",    fComponents, "");
     break;
   default:
-    addDirectory("", "platform/OpenBSD_Alpha-gcc3/components",    fComponents, "");
+    addDirectory("", "platform/OpenBSD/components",    fComponents, "");
   }
 
   err = getLastError();
@@ -142,15 +142,12 @@ if (!verifyDiskSpace(fProgram, srDest)) {
 
     registerChrome(PACKAGE | DELAYED_CHROME, getFolder("Chrome","enigmail.jar"), "content/enigmail/");
 
-    if (! isTbird) {
-      registerChrome(   SKIN | DELAYED_CHROME, getFolder("Chrome","enigmail-skin.jar"), "skin/modern/enigmail/");
+    registerChrome(   SKIN | DELAYED_CHROME, getFolder("Chrome","enigmail-skin-seamonkey.jar"), "skin/modern/enigmail/");
+
+    registerChrome(   SKIN | DELAYED_CHROME, getFolder("Chrome","enigmail-skin-seamonkey.jar"), "skin/classic/enigmail/");
 
-      registerChrome(   SKIN | DELAYED_CHROME, getFolder("Chrome","enigmail-skin.jar"), "skin/classic/enigmail/");
-    }
-    else {
-      registerChrome(   SKIN | DELAYED_CHROME, getFolder("Chrome","enigmail-skin-tbird.jar"), "skin/classic/enigmail/");
-    }
     registerChrome( LOCALE | DELAYED_CHROME, getFolder("Chrome","enigmail.jar"), "locale/en-US/enigmail/");
+    registerChrome( LOCALE | DELAYED_CHROME, getFolder("Chrome","enigmail-locale.jar"), "locale/ar/enigmail/");
     registerChrome( LOCALE | DELAYED_CHROME, getFolder("Chrome","enigmail-locale.jar"), "locale/ca-AD/enigmail/");
     registerChrome( LOCALE | DELAYED_CHROME, getFolder("Chrome","enigmail-locale.jar"), "locale/de-AT/enigmail/");
     registerChrome( LOCALE | DELAYED_CHROME, getFolder("Chrome","enigmail-locale.jar"), "locale/de-DE/enigmail/");
